@@ -62,6 +62,72 @@ local function is_english_candidate(cand)
     return true
 end
 
+-- 内部工具：获取当前十二时辰
+local function get_shichen(hour)
+    local shichen_map = {
+        "子时", "丑时", "寅时", "卯时", "辰时", "巳时",
+        "午时", "未时", "申时", "酉时", "戌时", "亥时"
+    }
+    -- 时辰算法：(小时 + 1) / 2，子时跨越 23:00 - 01:00
+    local index = math.floor((hour + 1) / 2) % 12 + 1
+    return shichen_map[index]
+end
+
+-- 核心：动态时间格式化（统一使用 \ 作为前缀）
+local function apply_datetime_format(text)
+    if not text or not string.find(text, "\\", 1, true) then 
+        return text 
+    end
+
+    local dt = os.date("*t")
+    local s = text
+
+    -- 1) 保护 [[...]] 块
+    local blocks = {}
+    s = s:gsub("%[%[(.-)%]%]", function(txt)
+        blocks[#blocks+1] = txt
+        return "\0BLK" .. #blocks .. "\0"
+    end)
+
+    -- 2) 计算时辰与刻钟
+    local ke_map = {"一刻", "二刻", "三刻", "四刻"}
+    local current_ke = ke_map[math.floor(dt.min / 15) + 1]
+    local current_shichen = get_shichen(dt.hour)
+
+    -- 3) 时间占位符映射表
+    local h12 = dt.hour % 12; if h12 == 0 then h12 = 12 end
+    local ampm = (dt.hour < 12) and "am" or "pm"
+    local raw_tz = os.date("%z") or "+0800"
+    local tz_colon = raw_tz:sub(1,3) .. ":" .. raw_tz:sub(4,5)
+
+    local time_map = {
+        Y = string.format("%04d", dt.year),
+        y = string.format("%02d", dt.year % 100),
+        m = string.format("%02d", dt.month),
+        d = string.format("%02d", dt.day),
+        n = tostring(dt.month),
+        j = tostring(dt.day),
+        H = string.format("%02d", dt.hour),  -- 24小时制数字
+        T = current_shichen,                -- 十二时辰（午时）
+        K = current_ke,                     -- 刻钟（三刻）
+        M = string.format("%02d", dt.min),
+        S = string.format("%02d", dt.sec),
+        p = ampm,
+        P = ampm:upper(),
+        O = tz_colon,
+        o = raw_tz
+    }
+
+    -- 4) 执行替换 \X
+    s = s:gsub("\\(%a)", function(char)
+        return time_map[char] or char 
+    end)
+
+    -- 5) 还原 [[...]]
+    s = s:gsub("\0BLK(%d+)\0", function(i) return blocks[tonumber(i)] or "" end)
+
+    return s
+end
 local escape_map = {
     ["\\n"] = "\n",            -- 换行
     ["\\r"] = "\r",            -- 回车
@@ -73,29 +139,28 @@ local escape_map = {
 local utf8_char_pattern = "[%z\1-\127\194-\244][\128-\191]*"
 
 local function apply_escape_fast(text)
-    if not text or (not find(text, "\\", 1, true) and not find(text, "{", 1, true)) then
+    -- 核心判断：如果不含反斜杠，直接跳过，保护性能
+    if not text or not find(text, "\\", 1, true) then
         return text, false
     end
 
     local new_text = text
-    if find(new_text, "\\{", 1, true) then
-        new_text = gsub(new_text, "\\{", "\1")
-    end
-    if find(new_text, "\\", 1, true) then
-        new_text = gsub(new_text, "\\[ntrsz]", escape_map)
-    end
-    if find(new_text, "{", 1, true) then
-        new_text = gsub(new_text, "(" .. utf8_char_pattern .. ")%{(%d+)}", function(char, count)
-            local n = tonumber(count)
-            if n and n > 0 and n < 200 then
-                return string.rep(char, n)
-            end
-            return char .. "{" .. count .. "}"
-        end)
-    end
-    if find(new_text, "\1", 1, true) then
-        new_text = gsub(new_text, "\1", "{")
-    end
+
+    -- 1. 处理基础字符转义 (\n, \t, \s 等)
+    new_text = gsub(new_text, "\\[ntrsz]", escape_map)
+
+    -- 2. 处理 \数字 重复功能 (如 a\3 => aaa)
+    new_text = gsub(new_text, "(" .. utf8_char_pattern .. ")\\(%d+)", function(char, count)
+        local n = tonumber(count)
+        -- 设置 200 的上限是为了防止恶意长字符串卡死引擎
+        if n and n > 0 and n < 200 then
+            return string.rep(char, n)
+        end
+        return char .. "\\" .. count
+    end)
+    -- 3. 处理动态时间占位符 (\Y, \T, \K 等)
+    new_text = apply_datetime_format(new_text)
+
     return new_text, new_text ~= text
 end
 
@@ -471,7 +536,7 @@ function M.init(env)
     env.table_idx = env.page_size
     if cfg then
         local tp = cfg:get_int("idiom_preposition")
-        if tp and tp > 1 and tp <= env.page_size then
+        if tp and tp >= 0 and tp <= env.page_size then
             env.table_idx = tp
         end
     end
@@ -564,7 +629,7 @@ function M.func(input, env)
     end
 
     local code_len = #code
-    local do_group = (code_len >= 2 and code_len <= 6)
+    local do_group = (env.table_idx > 0) and (code_len >= 2 and code_len <= 6)
 
     -- 闭包上下文 (Context)
     local function unify_tail_span(c)
